# uGecko
Python library for use with TCPGecko. Requires kernel exploit to use.

All the library is contained in the file named uGecko.py (*WARNING: Tested on Python 3.8 to 3.9*). You can find examples in the folder `examples`.

# Credits

**NWPlayer123, wj44, and wiiudev** for [`pyGecko`](https://github.com/wiiudev/pyGecko)<br />
**Chadderz and Marionumber1** for [`TCPGecko codehandler`](https://github.com/wiiudev/pyGecko/tree/master/codehandler)<br />
**BullyWiiPlaza** for the current version of [`TCPGecko`](https://github.com/BullyWiiPlaza/tcpgecko/)<br />
**VCoding** for this modified version of `pyGecko`, specially designed for the [`TCPGecko version`](https://github.com/BullyWiiPlaza/tcpgecko/) of **BullyWiiPlaza**.